@@ -3,13 +3,13 @@
 import zerorpc
 import os
 import pprint
-import workbench_client
+import client_helper
 
 def run():
     """This client pulls PCAP 'views' (view summarize what's in a sample)."""
     
     # Grab server args
-    args = workbench_client.grab_server_args()
+    args = client_helper.grab_server_args()
 
     # Start up workbench connection
     workbench = zerorpc.Client(timeout=300, heartbeat=60)
@@ -27,9 +27,10 @@ def run():
 
         # Process the pcap file
         with open(filename,'rb') as f:
-            md5 = workbench.store_sample(filename, f.read(), 'pcap')
+            base_name = os.path.basename(filename)
+            md5 = workbench.store_sample(f.read(), base_name, 'pcap')
             results = workbench.work_request('view_pcap', md5)
-            print '\n<<< %s >>>' % filename
+            print '\n<<< %s >>>' % base_name
             pprint.pprint(results)
 
 def test():
