@@ -21,7 +21,7 @@ def add_it(workbench, file_list, labels):
         if filename != '.DS_Store':
             with open(filename, 'rb') as pe_file:
                 base_name = os.path.basename(filename)
-                md5 = workbench.store_sample(base_name,  pe_file.read(), 'exe')
+                md5 = workbench.store_sample(pe_file.read(), base_name, 'exe')
                 workbench.add_node(md5, md5[:6], labels)
                 md5s.append(md5)
     return md5s
