@@ -3,13 +3,13 @@
 import zerorpc
 import os
 import pprint
-import workbench_client
+import client_helper
 
 def run():
     """This client shows workbench extacting files from a zip file."""
     
     # Grab server args
-    args = workbench_client.grab_server_args()
+    args = client_helper.grab_server_args()
 
     # Start up workbench connection
     workbench = zerorpc.Client(timeout=300, heartbeat=60)
@@ -20,20 +20,21 @@ def run():
     file_list = [os.path.join(data_path, child) for child in os.listdir(data_path)]
     for filename in file_list:
         with open(filename,'rb') as f:
-            md5 = workbench.store_sample(filename, f.read(), 'zip')
+            base_name = os.path.basename(filename)
+            md5 = workbench.store_sample(f.read(), base_name, 'zip')
             results = workbench.work_request('view', md5)
-            print 'Filename: %s ' % (filename)
+            print 'Filename: %s ' % (base_name)
             pprint.pprint(results)
 
             # The unzip worker gives you a list of md5s back
             # Run meta on all the unzipped files.
             results = workbench.work_request('unzip', md5)
-            print '\n*** Filename: %s ***' % (filename)
+            print '\n*** Filename: %s ***' % (base_name)
             for child_md5 in results['unzip']['payload_md5s']:
                 pprint.pprint(workbench.work_request('meta', child_md5))
 
 def test():
-    """Executes simple_workbench_client test."""
+    """Executes simple_client_helper test."""
     run()
 
 if __name__ == '__main__':
