@@ -48,7 +48,7 @@ class DataStore(object):
         """ Return the uri of the data store."""
         return self.uri
 
-    def store_sample(self, filename, sample_bytes, type_tag):
+    def store_sample(self, sample_bytes, filename, type_tag):
         """Store a sample into the datastore.
 
         Args:
@@ -60,6 +60,11 @@ class DataStore(object):
             Digest md5 digest of the sample.
         """
 
+        # Temp sanity
+        if len(filename) > 100:
+            print 'switched bytes/filename... %s %s' % (sample_bytes[:100], filename[:100])
+            exit(1)
+
         sample_info = {}
 
         # Compute the MD5 hash
@@ -114,14 +119,23 @@ class DataStore(object):
 
             # This should return the 'oldest' record in samples
             record = self.database[self.sample_collection].find().sort('import_time',pymongo.ASCENDING).limit(1)[0]
+            self.remove_sample(record['md5'])
 
-            # Delete it
-            print 'Deleting sample: %s (%.2f MB)...' % (record['md5'], record['length']/1024.0/1024.0)
-            self.database[self.sample_collection].remove({'md5': record['md5']})
-            self.gridfs_handle.delete(record['__grid_fs'])
+    def remove_sample(self, md5):
+        """Delete a specific sample"""
 
-            # Print info
-            print 'Sample Storage: %.2f out of %.2f MB' % (self.sample_storage_size(), self.samples_cap)
+        # Grab the sample
+        record = self.database[self.sample_collection].find_one({'md5': md5})
+        if not record:
+            return
+
+        # Delete it
+        print 'Deleting sample: %s (%.2f MB)...' % (record['md5'], record['length']/1024.0/1024.0)
+        self.database[self.sample_collection].remove({'md5': record['md5']})
+        self.gridfs_handle.delete(record['__grid_fs'])
+
+        # Print info
+        print 'Sample Storage: %.2f out of %.2f MB' % (self.sample_storage_size(), self.samples_cap)
 
     def clean_for_serialization(self, data):
         """Clean data in preparation for serialization.
@@ -263,7 +277,7 @@ class DataStore(object):
         sample = self.get_sample(md5)
         return True if sample else False
 
-    def list_samples(self, predicate={}):
+    def list_samples(self, predicate=None):
         """List all samples that meet the predicate or all if predicate is not specified.
 
         Args:
